#
# spec file for package touchegg
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           touchegg
Version:        2.0.17
Release:        1.4
Summary:        A multitouch gesture recogniser for GNU/Linux
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Hardware/Other
URL:            https://github.com/JoseExposito/touchegg
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         harden_touchegg.service.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  cmake(pugixml)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)
Obsoletes:      %{name}-gui

%description
Touchegg is an app that runs in the background and transforms the
gestures you make on your touchpad or touchscreen into visible
actions in your desktop.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%check
%ctest

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING COPYRIGHT
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}.conf
%{_sysconfdir}/xdg/autostart/%{name}.desktop

%changelog
* Sat May 25 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.0.17:
  * upstream packaging changes only
* Sun Apr  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to 2.0.16:
  * Do not use abstract socket on BSD
  * Fix compilation error on GCC 13
* Sun Nov 27 2022 Cor Blom <cornelis@solcon.nl>
- Update to 2.0.15:
  * Add TOUCHEGG_DEVICE_TYPE environment variable to RUN_COMMAND
  * Remove Firefox from the default config, it supports native gestures
* Tue Apr 26 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.14:
  * Performance improvements calculating the size of the animations
  * Fix crash that might happen when multiple input devices are added and
    removed
* Tue Feb 15 2022 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.0.13 (changes since 2.0.10):
  * Allow to display any animation on SEND_KEYS/RUN_COMMAND.
  * Add cyclic option to CHANGE_DESKTOP.
  * Improve pinch gesture detection on touchscreens.
  * Honour the XDG basedir specification.
  * Improve pinch detection when the fingers are placed
    horizontally or vertically.
  * Allow to run in multiple X displays.
  * Allow to configure the number of times a repeated action is
    executed.
* Thu Nov 25 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_touchegg.service.patch
* Mon Jun 14 2021 Richard Tsai <richard9404@gmail.com>
- Update to 2.0.10
  * Touchscreen: Use touch average to calculate deltas
  * libinput 1.18 support: Different deltas depending on libinput version
* Sat Apr 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.0.9
  * Use screen rotation to calculate touchscreen gestures direction
* Sat Apr  3 2021 Markus Ebner <info@ebner-markus.de>
- Update to 2.0.8
  * Fix animation when screens ot the same size are arranged vertically
  * Fix crash caused by a g_variant not being referenced
  * Handle the TOUCH_CANCEL event to avoid bugs
- Update to 2.0.7
  * Include different log levels, thanks to @imabuddha
  * Improvements in documentation
  * Fix intermittent crash
- Update to 2.0.6
  * New action added: `FULLSCREEN_WINDOW`. Thanks to @MarioJim
  * Use D-Bus for daemon-client communication, making easier to write clients different languages
  * Animations are pixel-precise at low speeds
  * Make application name case insensitive in config file
- Update to 2.0.5
  * Allow to cancel non animated gestures when configured to run on end. Thanks to @d86leader
  * Using unaccelerated deltas and different horizontal and vertical finish thresholds for a better
    user experience
  * Fix crashes when incorrect keys are used on `SEND_KEYS`
  * Handle devices reporting a size of 0x0 mm
  * Allow to use a symlink as configuration to Dotfiles users
  * Handles window managers that don't set the `_NET_WORKAREA` atom
- Update to 2.0.4
  * New gesture available for touchscreens: `TAP`
  * New action added: `MOUSE_CLICK`
  * Better multi-monitor support
  * Improve config file watcher
- Update to 2.0.3
  * Use `auto` with `color` and `borderColor` to use your theme's accent color
  * Use `auto` with `CHANGE_DESKTOP` to follow your natural scroll preferences
  * You are downloading a much better Debian (.deb) package
  * Now Linux distributions shipping Touchégg by default can update your configuration easily
  * Improve protocol backward compatibility for third party integrations
- Update to 2.0.2
  * Touchscreen support. Now you can use PINCH and SWIPE gestures on your touchscreen.
  * Animations are smoother, even in devices with limited resources like the Raspberry Pi 4.
  * CHANGE_DESKTOP now allows to use up/down/left/right directions in addition to previous/next.
    Made with love for KDE users.
  * Touchégg is added to startup automatically on installation.
  * In case you manually added it to startup you don't need to change anything, now you can not run
    multiple instances in parallel by mistake.
  * Fix Crash when a screen is connected but disabled. Thanks to @magnus-gross.
  * Fix Intermittent crash after editing the configuration file.
  * Fix Crash when performing a gesture on the root window.
- Update to 2.0.1
  * Fix Arch Linux and openSUSE compilation
- Update to 2.0.0
  * Total rewrite
  * Add libinput support
  * Add 1:1 animations so your gestures doesn't feel like a "shortcut" anymore
  * Drop the Qt dependency for better compatibility
  * Available gestures: SWIPE, PINCH
  * Available actions: MAXIMIZE_RESTORE_WINDOW, MINIMIZE_WINDOW, TILE_WINDOW,
    CLOSE_WINDOW, CHANGE_DESKTOP, SHOW_DESKTOP, SEND_KEYS, RUN_COMMAND
- Removed touchegg-1.1.1-slowdown-scroll-speed.patch
  Obsolete
- Removed touchegg-qt5.patch
  Obsolete
* Mon Mar 12 2018 sor.alexei@meowr.ru
- Add touchegg-qt5.patch: Build with Qt5.
- Add some missing dependencies.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Further spec cleanup.
- Use a tarball with bundled touchegg-gui.
- Add touchegg-gui subpackage.
- Add GPL-3.0+ to licenses (touchegg-gui license).
- Use optimised CFLAGS.
- Correct package group.
* Mon Dec 22 2014 tchvatal@suse.com
- Cleanup with spec-cleaner to be acceptable
* Sat Jun 22 2013 kamforbb@gmail.com
- Add patch touchegg-1.1.1-slowdown-scroll-speed.patch
* Sat May  7 2011 cabelo@opensuse.org
- Create package in openSuse Build : Alessandro de Oliveira Faria.
